Skip to contents

Takes an object of class fahb_design and plots the estimated operating characteristics of decision rules - based on standard progression criteria, an approximate Bayesian analysis, or both.

Usage

# S3 method for class 'fahb_design'
plot(x, ...)

Arguments

x

object of class fahb_design as produced by fahb_design().

...

further arguments passed to or from other methods.

Value

no return value, called for side effects.