Given the hyperparameters encoded in a fahb_problem object, return plots of
the three prior distributions and a plot of the prior predictive distribution
of the recruitment rate at a randomly selected site.
Examples
problem <- fahb_problem()
check_priors(problem)
#> [[1]]
#>
#> [[2]]
#>
#> [[3]]
#>
#> [[4]]
#> Warning: Removed 200 rows containing non-finite outside the scale range
#> (`stat_density()`).
#>