Takes an object of class fahb_analysis and plots the posterior
distributions of the predicted time for the trial to recruit and of the three
model parameters.
Usage
# S3 method for class 'fahb_analysis'
plot(x, ...)Takes an object of class fahb_analysis and plots the posterior
distributions of the predicted time for the trial to recruit and of the three
model parameters.
# S3 method for class 'fahb_analysis'
plot(x, ...)